:root{--ofx-accent-cyan: #00eaff;--ofx-accent-violet: #9b4dff;--ofx-accent-green: #4affc0;--ofx-accent-pink: #ff2ec6;--ofx-accent-gold: #ffb347;--ofx-bg-1: #0a0f1a;--ofx-bg-2: #05080f;--ofx-sidebar-bg: #0c131f;--ofx-card: rgba(255, 255, 255, 0.03);--ofx-glass-border: rgba(255, 255, 255, 0.05);--ofx-text: #d0d0e0;--ofx-comment: #6b7280;--ofx-accent-mix: rgb(93, 139.8, 255)}body{background:linear-gradient(180deg, #0a0f1a, #05080f);color:#d0d0e0;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;transition:background 220ms ease,color 220ms ease}.md-typeset>*+*{border-top:1px solid hsla(0,0%,100%,.02);margin-top:1.25rem;padding-top:1.25rem}.ofx-neon-sep{height:2px;background:linear-gradient(90deg, #00eaff, #9b4dff);opacity:.08;margin:1.25rem 0}h1.md-typeset__title,h1{color:#9b4dff;text-shadow:0 4px 28px rgba(155,77,255,.14);transition:color 150ms ease,text-shadow 220ms ease}h2,.md-typeset h2{position:relative;color:#d0d0e0}h2::after{content:"";display:block;width:48px;height:3px;margin-top:.45rem;background:linear-gradient(90deg, #00eaff, rgba(0, 0, 0, 0));border-radius:6px;opacity:.95}h3,h4,h5{color:rgb(93,139.8,255);transition:color 150ms ease,text-shadow 150ms ease}h3:hover,h4:hover,h5:hover{text-shadow:0 6px 18px rgba(0,234,255,.06),0 6px 24px rgba(155,77,255,.04)}.md-typeset h2+.ofx-neon-sep,.md-typeset h3+.ofx-neon-sep{margin-top:.6rem}.md-card,.md-content,.md-page{background:hsla(0,0%,100%,.03);border-radius:12px;border:1px solid hsla(0,0%,100%,.05);box-shadow:0 8px 28px rgba(2,6,23,.6),0 2px 12px rgba(0,0,0,.5);transition:transform 220ms ease,box-shadow 220ms ease,border-color 220ms ease}.md-card:hover,.md-content:hover{transform:translateY(-6px);box-shadow:0 18px 60px rgba(0,0,0,.6)}.md-nav__primary{background:#0c131f;border-right:1px solid hsla(0,0%,100%,.02)}.md-nav__item.md-nav__link--active,.md-nav__link--active{color:#00eaff !important;box-shadow:inset 4px 0 14px rgba(0,234,255,.08);border-left:3px solid rgba(0,234,255,.14)}.md-nav__link:hover{color:#9b4dff;text-shadow:0 2px 12px rgba(155,77,255,.06)}.md-nav__title{color:#9b4dff;border-bottom:1px solid rgba(155,77,255,.04)}.md-nav--secondary,.md-nav--toc{background:#0c131f}.md-nav--toc .md-nav__link--active{border-left:3px solid #00eaff;padding-left:.6rem}.md-button--primary,.md-btn,.md-button{background:linear-gradient(90deg, #00eaff, rgb(224.4, 252.48, 255));color:#041017;box-shadow:0 8px 30px rgba(0,234,255,.06);transition:transform 150ms ease,box-shadow 150ms ease,filter 150ms ease}.md-button--primary:hover{transform:translateY(-2px);box-shadow:0 18px 50px rgba(0,234,255,.1)}.badge,.md-chip{background:#9b4dff;color:#fff}.md-button--secondary{background:linear-gradient(90deg, #9b4dff, rgb(137.808988764, 46.4, 255));color:#fff}code,.md-inline-code{background:#141c2b;border:1px solid #00eaff;color:#00eaff;padding:.08rem .32rem;border-radius:8px}.md-typeset pre,pre[class*=language-]{background:rgba(14,20,31,.8);color:#e6eef6;border-radius:12px;padding:1rem;overflow:auto;border:1px solid hsla(0,0%,100%,.04);box-shadow:0 10px 36px rgba(0,0,0,.7),0 2px 14px rgba(0,234,255,.03);transition:box-shadow 150ms ease,transform 150ms ease}.md-typeset pre:hover{box-shadow:0 18px 60px rgba(0,0,0,.75),0 6px 28px rgba(0,234,255,.06)}.token.string{color:#4affc0}.token.attr-value{color:#4affc0}.token.number{color:#ffb347}.token.boolean{color:#ffb347}.token.keyword{color:#00eaff;font-weight:600}.token.operator{color:#00eaff}.token.function{color:#9b4dff}.token.class-name{color:#9b4dff}.token.comment,.token.prolog,.token.doctype,.token.cdata{color:#6b7280;font-style:italic}.md-typeset pre::after{content:"";position:absolute;left:0;right:0;top:0;bottom:0;pointer-events:none;border-radius:12px;box-shadow:0 6px 40px rgba(0,234,255,.02) inset}a,a code{color:#00eaff;text-decoration:none}a:hover{color:#9b4dff;text-shadow:0 6px 28px rgba(155,77,255,.04)}em{color:#ffb347;font-style:normal;font-weight:600}ul li::marker{color:#00eaff}ol li::marker{color:#ffb347}.md-header{position:relative;overflow:visible}.md-header::before{content:"";position:absolute;left:0;right:0;top:0;height:4px;background:linear-gradient(90deg, #00eaff, #9b4dff, #ffb347);opacity:.06;animation:ofx-header-shift 10s linear infinite}@keyframes ofx-header-shift{0%{background-position:0%}100%{background-position:200%}}.ofx-glow{box-shadow:0 8px 40px rgba(0,234,255,.06)}.ofx-pill{padding:.25rem .6rem;border-radius:999px}.md-typeset h1,.md-typeset h2,.md-typeset h3{color:#d0d0e0}
